==> replacer-0.3.0%2B1.21.%282%2B%29-Fabric-sources.jar: eva/replacer/mixin/client/BlockItemMixin.java <==
package eva.replacer.mixin.client;

import eva.replacer.RePlacerClient;
import eva.replacer.util.BuildHolder;
import eva.replacer.util.RelPos;
import net.minecraft.class_1269;
import net.minecraft.class_1657;
import net.minecraft.class_1747;
import net.minecraft.class_1750;
import net.minecraft.class_2338;
import net.minecraft.class_2561;
import net.minecraft.class_3468;
import net.minecraft.class_3965;
import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.Unique;
import org.spongepowered.asm.mixin.injection.At;
import org.spongepowered.asm.mixin.injection.Inject;
import org.spongepowered.asm.mixin.injection.callback.CallbackInfoReturnable;

import static eva.replacer.RePlacerClient.isHeldOrToggled;
import static eva.replacer.config.RePlacerConfig.*;
import static eva.replacer.util.BuildHolder.rotate;
import static eva.replacer.util.BuildHolder.setBaseDir;

@Mixin(class_1747.class)
public class BlockItemMixin {

    @Unique private final class_1747 blit = (class_1747) (Object) this;
    @Unique private boolean rePlacing = false;
    @Inject(
            method = "place",
            at = @At("TAIL")
    )
    private void placeAgain(class_1750 context, CallbackInfoReturnable<class_1269> cir) {
        if (rePlacing)
            return;
        if (reCording) {
            buildSaver(context);
            return;
        }
        if (!isHeldOrToggled()) return;
        class_2338 pos0 = context.method_8037();
        class_1657 player = context.method_8036();
        assert player != null;
        rePlacing = true;
        RelPos.setBase(pos0);
        try {
            setBaseDir(context.method_8038());
            BuildHolder build = rotate(getBuild());
            for (RelPos pos : build.posList()) {
                if (pos.equals(new RelPos(new int[]{0,0,0}))) {
                    continue;
                }
                if (player.method_37908().method_8320(pos.pos()).method_45474()) {
                    blit.method_7712(new class_1750(
                                    player,
                                    context.method_20287(),
                                    player.method_5998(context.method_20287()),
                                    new class_3965(
                                            pos.vec(),
                                            context.method_8038(),
                                            pos.pos(),
                                            context.method_17699()
                                    )
                            )
                    );
                    player.method_7259(class_3468.field_15372.method_14956(blit));
                }
            }
        } catch (Exception ignored) {
            RePlacerClient.LOGGER.info("Failed to get build!");
            player.method_7353(class_2561.method_43470("Failed to get build!"), false);
        }
        setBaseDir(null);
        rePlacing = false;
    }
}

==> replacer-0.4.0%2B1.21.%282%2B%29-Fabric-sources.jar: eva/replacer/mixin/client/BlockItemMixin.java <==
package eva.replacer.mixin.client;

import eva.replacer.RePlacerClient;
import eva.replacer.util.BuildHolder;
import eva.replacer.util.RelPos;
import net.minecraft.class_1269;
import net.minecraft.class_1657;
import net.minecraft.class_1747;
import net.minecraft.class_1750;
import net.minecraft.class_2561;
import net.minecraft.class_3468;
import net.minecraft.class_3965;
import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.Unique;
import org.spongepowered.asm.mixin.injection.At;
import org.spongepowered.asm.mixin.injection.Inject;
import org.spongepowered.asm.mixin.injection.callback.CallbackInfoReturnable;

import static eva.replacer.RePlacerClient.isHeldOrToggled;
import static eva.replacer.config.RePlacerConfig.*;
import static eva.replacer.util.BuildHolder.rotate;
import static eva.replacer.util.BuildHolder.setBaseDir;

@Mixin(class_1747.class)
public class BlockItemMixin {

    @Unique private final class_1747 blit = (class_1747) (Object) this;
    @Unique private boolean rePlacing = false;
    @Inject(
            method = "place",
            at = @At("TAIL")
    )
    private void placeAgain(class_1750 context, CallbackInfoReturnable<class_1269> cir) {
        if (rePlacing)
            return;
        if (reCording) {
            if (buildSaver(context)) {
                assert context.method_8036() != null;
                context.method_8036().method_7353(class_2561.method_43470("Central block saved!"), true);
            }
            return;
        }
        if (!isHeldOrToggled()) return;
        class_1657 player = context.method_8036();
        assert player != null;
        rePlacing = true;
        RelPos.setBase(context.method_17698(), context.method_8037());
        try {
            setBaseDir(context.method_8038());
            BuildHolder build = rotate(getBuild());
            for (RelPos pos : build.posList()) {
                if (pos.equals(new RelPos(new int[]{0,0,0}))) {
                    continue;
                }
                if (context.method_8041().method_7960()) break;
                if (player.method_37908().method_8320(pos.pos()).method_45474()) {
                    blit.method_7712(new class_1750(
                                    player,
                                    context.method_20287(),
                                    player.method_5998(context.method_20287()),
                                    new class_3965(
                                            pos.vec(),
                                            context.method_8038(),
                                            pos.pos(),
                                            context.method_17699()
                                    )
                            )
                    );
                    player.method_7259(class_3468.field_15372.method_14956(blit));
                }
            }
        } catch (Exception ignored) {
            RePlacerClient.LOGGER.info("Failed to get build!");
            player.method_7353(class_2561.method_43470("Failed to get build!"), false);
        }
        setBaseDir(null);
        rePlacing = false;
    }
}
